@@ -1167,7 +1167,8 @@ def ensure_unique(iterable, key=lambda x: x):
     """
     Wrap an iterable to raise a ValueError if non-unique values are encountered.
 
-    >>> consume(ensure_unique('abc'))
+    >>> list(ensure_unique('abc'))
+    ['a', 'b', 'c']
     >>> consume(ensure_unique('abca'))
     Traceback (most recent call last):
     ...
